Module: Decidim::AriaSelectedLinkToHelper
- Included in:
- ProfileCell
- Defined in:
- app/helpers/decidim/aria_selected_link_to_helper.rb
Overview
Module to add the attribute aria-selected to links when they are
pointing to the current path. Uses the active_link_to gem to calculate
this.
Instance Method Summary collapse
-
#aria_selected_link_to(text, link, options = {}) ⇒ Object
Adds the
aria-selectedattribute to a link when it is pointing to the current path.
Instance Method Details
#aria_selected_link_to(text, link, options = {}) ⇒ Object
Adds the aria-selected attribute to a link when it is pointing to the
current path. The API is the same than the link_to one, and uses this
helper internally.
text - a String with the link text
link - Where the link should point to. Accepts the same value than
link_to helper.
options - An options Hash that will be passed to link_to.
17 18 19 20 21 22 23 24 25 |
# File 'app/helpers/decidim/aria_selected_link_to_helper.rb', line 17 def aria_selected_link_to(text, link, = {}) link_to( text, link, .merge( "aria-selected": is_active_link?(link, [:aria_link_type] || :inclusive) ) ) end |