Class: Decidim::CardSCell

Inherits:
ViewModel
  • Object
show all
Defined in:
app/cells/decidim/card_s_cell.rb

Overview

This cell is used a base for all Search cards. It holds the basic layout so other cells only have to customize a few methods or overwrite views.

Instance Method Summary collapse

Instance Method Details

#showObject



9
10
11
# File 'app/cells/decidim/card_s_cell.rb', line 9

def show
  render
end