Class: Decidim::ContentBlocks::ParticipatorySpaceHeroCell

Inherits:
BaseCell
  • Object
show all
Defined in:
app/cells/decidim/content_blocks/participatory_space_hero_cell.rb

Constant Summary

Constants inherited from BaseCell

BaseCell::SCOPE_ASSOCIATIONS

Constants included from AmendmentsHelper

AmendmentsHelper::TOTAL_STEPS

Instance Method Summary collapse

Methods inherited from BaseCell

#resource

Methods inherited from ViewModel

#call, #current_user, #view_context

Methods included from IconHelper

#component_icon, #manifest_icon, #resource_icon, #resource_type_icon, #resource_type_icon_key, #text_with_resource_icon

Methods included from LayoutHelper

#_icon_classes, #apple_favicon, #application_path, #current_url, #current_user_unread_data, #external_icon, #favicon, #icon, #legacy_favicon, #role, #root_url

Methods included from TooltipHelper

#with_tooltip

Methods included from ModalHelper

#decidim_drawer, #decidim_modal

Methods included from OrganizationHelper

#current_organization_name, #organization_colors, #organization_description_label, #organization_name

Methods included from TranslatableAttributes

#attachment?, #default_locale?

Methods included from ApplicationHelper

#add_body_classes, #cell, #edit_link, #extra_admin_link, #html_truncate, #layout_item_classes, #present, #prevent_timeout_seconds, #resolve_presenter_class, #text_initials

Methods included from Decidim::CacheHelper

#cache

Methods included from AmendmentsHelper

#accept_and_reject_buttons_for, #action_button_card_for, #allowed_to_accept_and_reject?, #allowed_to_promote?, #amendments_enabled?, #amendments_form_field_for, #amendments_form_fields_label, #amendments_form_fields_value, #can_participate_in_private_space?, #can_react_to_emendation?, #current_step, #emendation_actions_for, #emendation_announcement_for, #promote_button_for, #render_emendation_body, #total_steps, #wizard_aside_back_url, #wizard_header_title

Methods included from RichTextEditorHelper

included, #text_editor_for

Methods included from Decidim::ContextualHelpHelper

#floating_help

Methods included from DecidimFormHelper

#areas_for_select, #base_error_messages, #decidim_form_for, #decidim_form_slug_url, #editor_field_tag, #form_field_has_error?, #form_required_explanation, #name_with_locale, #tab_element_class_for, #translated_field_tag

Methods included from OmniauthHelper

#normalize_provider_name, #oauth_icon, #provider_name

Methods included from SanitizeHelper

#decidim_escape_translated, #decidim_html_escape, #decidim_rich_text, #decidim_sanitize, #decidim_sanitize_admin, #decidim_sanitize_editor, #decidim_sanitize_editor_admin, #decidim_sanitize_newsletter, #decidim_sanitize_translated, #decidim_url_escape, included

Methods included from MarkupHelper

#element_id

Methods included from ReplaceButtonsHelper

#button_to, #submit_tag

Methods included from ActionAuthorizationHelper

#action_authorized_button_to, #action_authorized_link_to, #logged_button_to, #logged_link_to

Methods included from ResourceHelper

#linked_classes_filter_values_for, #linked_classes_for, #resource_locator

Instance Method Details

#cta_pathObject



14
15
16
17
18
# File 'app/cells/decidim/content_blocks/participatory_space_hero_cell.rb', line 14

def cta_path
  return unless model

  @cta_path ||= translated_attribute(model.settings.button_url).presence
end

#cta_textObject



8
9
10
11
12
# File 'app/cells/decidim/content_blocks/participatory_space_hero_cell.rb', line 8

def cta_text
  return unless model

  @cta_text ||= translated_attribute(model.settings.button_text).presence
end

#has_cta?Boolean

Returns:

  • (Boolean)


38
39
40
# File 'app/cells/decidim/content_blocks/participatory_space_hero_cell.rb', line 38

def has_cta?
  [cta_text, cta_path].all?
end

#image_pathObject

If it is called from the landing page content block, use the background image defined there Else, use the banner image defined in the space (for assemblies)



32
33
34
35
36
# File 'app/cells/decidim/content_blocks/participatory_space_hero_cell.rb', line 32

def image_path
  return model.images_container.attached_uploader(:background_image).url if model.respond_to?(:images_container)

  attached_uploader(:banner_image).url
end

#subtitle_textObject



24
25
26
27
28
# File 'app/cells/decidim/content_blocks/participatory_space_hero_cell.rb', line 24

def subtitle_text
  return unless resource.respond_to?(:subtitle)

  decidim_escape_translated(resource.subtitle)
end

#title_textObject



20
21
22
# File 'app/cells/decidim/content_blocks/participatory_space_hero_cell.rb', line 20

def title_text
  decidim_escape_translated(title)
end