Module: Decidim::Geocodable
- Extended by:
- ActiveSupport::Concern
- Defined in:
- lib/decidim/geocodable.rb
Overview
This concern overrides some of the Active Record functionality injected by
the Geocoder gem in order to pass the geocoding searches through Decidim's
own API which configures the geocoder correctly for each search. This is
used when the model.geocode and model.reverse_geocode methods are called
for the Active Record models.
NOTE: This module is automatically loaded for all active record models in the "decidim_core.geocoding_extensions" initializer. It does not need to be included separately into any models.
Defined Under Namespace
Modules: RecordGeocoder