Module: Decidim::HasWorkflows

Extended by:
ActiveSupport::Concern
Defined in:
lib/decidim/has_workflows.rb

Overview

A concern to include logic to manage workflows inside a module. The method workflow_manifest_class must be implemented returning the class which implements the workflow manifest API