Class: Decidim::HighlightedParticipatoryProcessCell

Inherits:
ViewModel
  • Object
show all
Includes:
CardHelper
Defined in:
app/cells/decidim/highlighted_participatory_process_cell.rb

Overview

It is used in the menu bar dropdown with a helper that returns the highlighted participatory process of the current organization:

<%= cell("decidim/highlighted_participatory_process", menu_highlighted_participatory_process) %>

Method Summary

Methods included from CardHelper

#card_for