Module: Decidim::Likeable
- Extended by:
- ActiveSupport::Concern
- Defined in:
- lib/decidim/likeable.rb
Overview
This concern contains the logic related with resources that can be liked.
Thus, it is expected to be included into a resource that is wanted to be likeable.
This resource will have many Decidim::Likes.