Class: Decidim::MemberCell
- Inherits:
-
ViewModel
- Object
- ViewModel
- Decidim::MemberCell
- Defined in:
- app/cells/decidim/member_cell.rb
Overview
This cell renders the card for an instance of an Assembly member
This cell renders the card for an instance of an Assembly member