Class: Decidim::NavbarAdminLinkCell

Inherits:
ViewModel
  • Object
show all
Defined in:
app/cells/decidim/navbar_admin_link_cell.rb

Overview

This cell renders a link in the top navbar so admins can easily manage data without having to look for it at the admin panel when they are at a public page. example use:

<%= cell("decidim/navbar_admin_link", { link_url: link_url, link_options: link_options }) %>

Instance Method Summary collapse

Instance Method Details

#showObject



11
12
13
# File 'app/cells/decidim/navbar_admin_link_cell.rb', line 11

def show
  render if link_url
end