Module: Decidim::ParticipatorySpaceResourceable
- Extended by:
- ActiveSupport::Concern
- Defined in:
- lib/decidim/participatory_space_resourceable.rb
Overview
Participatory Space Resourceable is a concern with the
features needed when you want to link a space
(for example Participatory Process) to another space (Assembly).
The main difference between the two concerns Resourceable and
ParticipatorySpaceResourceable is that the first one is linking
component types between them, for example Budgets with Proposals and
therefore depend on a Component.
The second one, ParticipatorySpaceResourceable, it is used for linking
ParticipatorySpaces to each other, and therefore do not depend on a
Component but rather that they depend to the Organization.