Module: Decidim::SoftDeletable
- Extended by:
- ActiveSupport::Concern
- Included in:
- Component
- Defined in:
- lib/decidim/soft_deletable.rb
Overview
This concern contains the logic related to soft deletion (trashing).
This concern contains the logic related to soft deletion (trashing).