Module: Decidim::Taxonomizable

Extended by:
ActiveSupport::Concern
Included in:
ActionLog
Defined in:
lib/decidim/taxonomizable.rb

Overview

A concern with the components needed when you want a model to have taxonomies.

The including model needs to implement the following interface:

@abstract method that gives an associated organization @method organization @return [Decidim::Organization]