Class: Decidim::TranslationBarCell
- Inherits:
-
ViewModel
- Object
- ViewModel
- Decidim::TranslationBarCell
- Defined in:
- app/cells/decidim/translation_bar_cell.rb
Overview
This cell is used to render a button to toggle machine translations. It will only render if the translations are enabled.
Instance Method Summary collapse
Instance Method Details
#button_text ⇒ Object
38 39 40 41 42 43 44 |
# File 'app/cells/decidim/translation_bar_cell.rb', line 38 def if must_render_translation?(model) t("decidim.translation_bar.show_original") else t("decidim.translation_bar.show_translated") end end |
#help_text ⇒ Object
46 47 48 |
# File 'app/cells/decidim/translation_bar_cell.rb', line 46 def help_text t("decidim.translation_bar.help_text") end |
#link ⇒ Object
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 |
# File 'app/cells/decidim/translation_bar_cell.rb', line 18 def link original_url = request.original_url parsed_url = URI.parse(original_url) query = parsed_url.query new_query_params = "toggle_translations=true" new_query = if RequestStore.store[:toggle_machine_translations] query.gsub("toggle_translations=true", "") elsif query.nil? new_query_params else "#{query}&#{new_query_params}" end parsed_url.query = new_query url = parsed_url.to_s link_to , url, class: "button button__sm button__transparent-secondary" end |
#renderable? ⇒ Boolean
13 14 15 16 |
# File 'app/cells/decidim/translation_bar_cell.rb', line 13 def renderable? Decidim.config.enable_machine_translations && model.enable_machine_translations end |
#show ⇒ Object
7 8 9 10 11 |
# File 'app/cells/decidim/translation_bar_cell.rb', line 7 def show return unless renderable? render end |