Class: Decidim::UnlikeResource
- Defined in:
- app/commands/decidim/unlike_resource.rb
Overview
A command with all the business logic to unlike a resource.
Instance Method Summary collapse
-
#call ⇒ Object
Executes the command.
-
#initialize(resource, current_user) ⇒ UnlikeResource
constructor
Public: Initializes the command.
Methods inherited from Command
call, #evaluate, #method_missing, #respond_to_missing?, #transaction, #with_events
Constructor Details
#initialize(resource, current_user) ⇒ UnlikeResource
Public: Initializes the command.
resource - A Decidim::Likeable object. current_user - The current user.
10 11 12 13 |
# File 'app/commands/decidim/unlike_resource.rb', line 10 def initialize(resource, current_user) @resource = resource @current_user = current_user end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Decidim::Command
Instance Method Details
#call ⇒ Object
Executes the command. Broadcasts these events:
-
:ok when everything is valid, together with the resource.
-
:invalid if the form was not valid and we could not proceed.
Returns nothing.
21 22 23 24 |
# File 'app/commands/decidim/unlike_resource.rb', line 21 def call destroy_resource_like broadcast(:ok, @resource) end |