Class: Decidim::UploadValidationForm

Inherits:
Form
  • Object
show all
Includes:
HasUploadValidations
Defined in:
app/forms/decidim/upload_validation_form.rb

Overview

A form object used to handle upload validations, this is used when user is adding files to dropzone in upload modal.

Defined Under Namespace

Classes: AttachmentContextProxy

Instance Method Summary collapse

Methods included from HasUploadValidations

#attached_uploader, #maximum_avatar_size, #maximum_upload_size

Instance Method Details

#attached_toObject

This is a "trick" to provide the attachment context (i.e. admin or participant) to the attachment records being validated. This is to show the invalid content type / file extension errors with the correct file extensions that may be shown in the help text next to the upload drag'n'drop field.



28
29
30
# File 'app/forms/decidim/upload_validation_form.rb', line 28

def attached_to
  @attached_to ||= AttachmentContextProxy.new(organization, attachment_context)
end