Class: Decidim::UserGroupMailer

Inherits:
ApplicationMailer show all
Defined in:
app/mailers/decidim/user_group_mailer.rb

Instance Method Summary collapse

Methods included from OrganizationHelper

#current_organization_name, #organization_colors, #organization_description_label, #organization_name

Methods included from TranslatableAttributes

#attachment?, #default_locale?

Methods included from SanitizeHelper

#decidim_escape_translated, #decidim_html_escape, #decidim_rich_text, #decidim_sanitize, #decidim_sanitize_admin, #decidim_sanitize_editor, #decidim_sanitize_editor_admin, #decidim_sanitize_newsletter, #decidim_sanitize_translated, #decidim_url_escape, included

Instance Method Details

#notify_deprecation_to_member(user, group_name, group_email) ⇒ Object

Deprecated.

This mailer will be removed in decidim v0.32.0

This is a mailer that aids migration from the old user_groups to the new user group system This should be used only in the scope of the migration process



22
23
24
25
26
27
28
29
30
31
32
# File 'app/mailers/decidim/user_group_mailer.rb', line 22

def notify_deprecation_to_member(user, group_name, group_email)
  with_user(user) do
    @user = user
    @group_name = group_name
    @group_email = group_email
    @organization = user.organization

    subject = I18n.t("notify_deprecation_to_member.subject", scope: "decidim.user_group_mailer")
    mail(to: user.email, subject:)
  end
end

#notify_deprecation_to_owner(group) ⇒ Object

Deprecated.

This mailer will be removed in decidim v0.32.0

This is a mailer that aids migration from the old user_groups to the new user group system This should be used only in the scope of the migration process



8
9
10
11
12
13
14
15
16
17
# File 'app/mailers/decidim/user_group_mailer.rb', line 8

def notify_deprecation_to_owner(group)
  with_user(group) do
    @group_name = group.name
    @group_email = group.email
    @organization = group.organization

    subject = I18n.t("notify_deprecation_to_owner.subject", scope: "decidim.user_group_mailer")
    mail(to: group.email, subject:)
  end
end

#notify_user_group_patched(group, user, password) ⇒ Object

Deprecated.

This mailer will be removed in decidim v0.32.0

This is a mailer that aids migration from the old user_groups to the new user group system This should be used only in the scope of the migration process



37
38
39
40
41
42
43
44
45
46
47
# File 'app/mailers/decidim/user_group_mailer.rb', line 37

def notify_user_group_patched(group, user, password)
  with_user(user) do
    @group = group
    @user = user
    @password = password
    @organization = user.organization

    subject = I18n.t("notify_user_group_patched.subject", scope: "decidim.user_group_mailer")
    mail(to: user.email, subject:)
  end
end