Class: FileContentTypeValidator
- Inherits:
-
ActiveModel::Validations::FileContentTypeValidator
- Object
- ActiveModel::Validations::FileContentTypeValidator
- FileContentTypeValidator
- Defined in:
- app/validators/file_content_type_validator.rb
Overview
This is just to make Zeitwerk happy. The actual validator that gets priority
is the class above as all validators in the ActiveModel::Validations
namespace will be used primarily and only if a matching validator is not found
in that namespace, the ones at the root level are used.