Class: Decidim::CardLCell
- Inherits:
-
ViewModel
- Object
- ViewModel
- Decidim::CardLCell
- Includes:
- Cell::ViewModel::Partial, CardHelper, LayoutHelper, SearchesHelper, TooltipHelper
- Defined in:
- app/cells/decidim/card_l_cell.rb
Overview
This cell is used a base for all List cards. It holds the basic layout so other cells only have to customize a few methods or overwrite views.
Instance Method Summary collapse
Methods included from SearchesHelper
#main_search_path, #search_path_by, #search_path_by_resource_type, #search_path_by_state_link, #searchable_resource_human_name
Methods included from LayoutHelper
#_icon_classes, #apple_favicon, #application_path, #current_url, #current_user_unread_data, #external_icon, #favicon, #icon, #legacy_favicon, #role, #root_url
Methods included from TooltipHelper
Methods included from ModalHelper
#decidim_drawer, #decidim_modal
Methods included from OrganizationHelper
#current_organization_name, #organization_colors, #organization_description_label, #organization_name
Methods included from TranslatableAttributes
#attachment?, #default_locale?
Methods included from CardHelper
Instance Method Details
#show ⇒ Object
15 16 17 |
# File 'app/cells/decidim/card_l_cell.rb', line 15 def show render end |