Class: Decidim::HighlightedParticipatoryProcessCell
- Inherits:
-
ViewModel
- Object
- ViewModel
- Decidim::HighlightedParticipatoryProcessCell
- Includes:
- CardHelper
- Defined in:
- app/cells/decidim/highlighted_participatory_process_cell.rb
Overview
It is used in the menu bar dropdown with a helper that returns the highlighted participatory process of the current organization:
<%= cell("decidim/highlighted_participatory_process", menu_highlighted_participatory_process) %>