Class: Decidim::NavLinksCell
- Inherits:
-
ViewModel
- Object
- ViewModel
- Decidim::NavLinksCell
- Defined in:
- app/cells/decidim/nav_links_cell.rb
Overview
This cell is intended to be used on participatory spaces show or related content blocks The cell receive an array of nav items represented by a hash with :url and :name keys