Class: Decidim::ProgressBarCell
- Defined in:
- app/cells/decidim/progress_bar_cell.rb
Overview
This cell renders a collapsible list of elements. Each element from the
model array will be rendered with the :cell cell.
The model must be an Integer representing how many elements we have right
now. Can be higher than the :total options value.
Available options:
:small=> Whether the progress bar should be small or not. This will probably be set totrueif rendered in a collection view. Defaults tofalse.:total=> The amount that will set the progress bar to 100%, the objective to reach.:units_name=> The I18n key representing the name of the elements we're counting (votes, signatures, answers...). Can have the%{count}format.:element_id=> A String representing the ID that will be given to the progress bar HTML element.:subtitle_text=> An I18n key representing a subtitle for the element.
Example:
cell(
"decidim/progress_bar",
7,
element_id: "my-id",
units_name: "my.i18n.key",
small: true,
total: 10,
subtitle_text: I18n.t("my.subtitle.key")
)
Method Summary
Methods inherited from ViewModel
Methods included from ReplaceButtonsHelper
Methods included from ActionAuthorizationHelper
#action_authorized_button_to, #action_authorized_link_to, #logged_button_to, #logged_link_to
Methods included from ScopesHelper
#has_visible_scopes?, #scope_name_for_picker, #scopes_picker_field, #scopes_picker_filter, #scopes_picker_tag
Methods included from TranslatableAttributes
Methods included from DecidimFormHelper
#areas_for_select, #base_error_messages, #decidim_form_for, #decidim_form_slug_url, #editor_field_tag, #form_field_has_error?, #form_required_explanation, #name_with_locale, #scopes_picker_field_tag, #tab_element_class_for, #translated_field_tag
Methods included from ResourceHelper
#linked_classes_filter_values_for, #linked_classes_for, #linked_resources_for, #resource_locator, #resource_title