Module: Decidim::Taxonomizable
Overview
A concern with the components needed when you want a model to have taxonomies.
The including model needs to implement the following interface:
@abstract method that gives an associated organization
@method organization
@return [Decidim::Organization]