Class: Decidim::WizardStepFormCell
- Inherits:
-
ViewModel
- Object
- ViewModel
- Decidim::WizardStepFormCell
- Defined in:
- app/cells/decidim/wizard_step_form_cell.rb
Overview
This cell renders the wizard step form :wizard_aside or :wizard_header view. Is designed to be used by different models and so it does not try to compute the information likely to change. Expects a Hash with all necessary data.
Instance Method Summary collapse
Instance Method Details
#show ⇒ Object
8 9 10 |
# File 'app/cells/decidim/wizard_step_form_cell.rb', line 8 def show render view end |